@@ -76,7 +76,7 @@ function(lm.out, cook, cooks_cut,
   color <- getOption("pt_color")
   points(fit.ord, res_ord, pch=21, col=color, bg=fill, cex=0.76)
 
-  abline(h=0, lty="dotted", lwd=1.5, col=getOption("bar_fill_ordered"))
+  abline(h=0, lty="dotted", lwd=1.5, col=getOption("bar_fill_cont"))
   lines(lowess(fit.ord, res_ord, f=.9), col=getOption("pt_color"))
   res_c <- res[which(cook >= cooks_cut)]
   fit.c <- fit[which(cook >= cooks_cut)]
