@@ -24,20 +24,21 @@ function(YA, bw1, Ynm, digits_d, brief,
   if (!grepl("gray", getOption("theme"))) {
     col.1 <- rgb(.63,.46,.15)
     col.m1 <- rgb(.71,.65,.65)
-#    col.1t <- rgb(.63,.46,.15, alpha=.7)
   }
   else {
     col.1 <- rgb(.40,.40,.40)
     col.m1 <- rgb(.40,.40,.40)
-#    col.1t <- rgb(.40,.40,.40, alpha=.7)
   }
-  col.2 <- rgb(.49,.56,.69)
+# col.2 <- rgb(.49,.56,.69)
+  col.2 <- "gray30"
 
-  col.1t <- getOption("bar_color")
+# col.1t <- getOption("bar_color")
+  col.1t <- "gray50"
   col.1d <- getOption("ellipse_fill")
 
   col.tx <- getOption("lab_color")
-  col.ln <- getOption("bar_color")
+# col.ln <- getOption("bar_color")
+  col.ln <- "gray50"
 
 
   # ------------------------------ 
@@ -58,8 +59,6 @@ function(YA, bw1, Ynm, digits_d, brief,
   if (nchar(xl) > 52) xl <- paste(substr(xl,1,50), "...")
   title(xlab=x.lab, col.lab=col.tx)
 
-  xleft <- par("usr")[1]  # left side of graph
-  xright <- par("usr")[2]  # right side of graph
   ybot <- par("usr")[3]  # bottom of graph
   ytop <- par("usr")[4]  # height of graph
 
@@ -89,8 +88,10 @@ function(YA, bw1, Ynm, digits_d, brief,
     mid <- (m1 + mu) / 2
     lr <- mid + .5*mmd  # line right
     ll <- mid - .5*mmd  # line left
-    lines(c(lr,lr), c(ybot+.44*max.y,ytop-.44*max.y), lty="solid", lwd=2, col=col.e)
-    lines(c(ll,ll), c(ybot+.44*max.y,ytop-.44*max.y), lty="solid", lwd=2, col=col.e)
+    lines(c(lr,lr), c(ybot+.44*max.y,ytop-.44*max.y), lty="solid", lwd=2,
+          col=col.e)
+    lines(c(ll,ll), c(ybot+.44*max.y,ytop-.44*max.y), lty="solid", lwd=2,
+          col=col.e)
     text(mid, ybot+.41*max.y, label=toString(.fmt(mmd,2)), col=col.e)
     text(mid, ytop-.41*max.y, label=toString(.fmt(msmd,2)), col=col.e)
     text(mid, ybot+.38*max.y, label="mmd", col=col.e)
@@ -116,7 +117,8 @@ function(YA, bw1, Ynm, digits_d, brief,
     last.coord.x <- x.i
   }
   # connect last seg to top
-  segments(last.coord.x, max.y+.025*max.y, last.coord.x, ytop, lwd=1, col=col.d.unit)
+  segments(last.coord.x, max.y+.025*max.y, last.coord.x, ytop, lwd=1,
+           col=col.d.unit)
   # print d value towards top
   text((m1+mu)/2, ytop-.07*max.y, label=.fmt(smd), col=col.d.unit, cex=.9)
   # horiz bar connects means
@@ -125,7 +127,8 @@ function(YA, bw1, Ynm, digits_d, brief,
   text((m1+mu)/2, ytop-.11*max.y, label="d", col=col.d.unit, cex=.9)
 
   # print mdiff value towards bottom  
-  text((m1+mu)/2, ybot+.11*max.y, label=.fmt(mdiff, digits_d), col=col.d.unit, cex=.9)
+  text((m1+mu)/2, ybot+.11*max.y, label=.fmt(mdiff, digits_d), col=col.d.unit,
+        cex=.9)
   # horiz bar connects means
   segments(mlow, ybot+.09*max.y, mhi, ybot+.09*max.y, col=col.d.unit, lwd=1)
   # print diff towards bottom
@@ -133,8 +136,8 @@ function(YA, bw1, Ynm, digits_d, brief,
 
   # title area, above graph
   if (show_title) {
-    mtext(paste("One-Group Plot with Mean and Null Mean"), side=3, line=6.6, font=2,
-          col=col.tx)
+    mtext(paste("One-Group Plot with Mean and Null Mean"), side=3, line=6.6,
+                font=2, col=col.tx)
     mtext(paste("Analyze",Ynm), side=3, line=5.4, font=3, cex=.9,
           col=col.tx)
     mtext(bquote(paste("  t-test of mu=", .(mu), ":   t = ", .(.fmt(tvalue,3)), 
@@ -144,7 +147,8 @@ function(YA, bw1, Ynm, digits_d, brief,
       .(.fmt(lb,3)), " to ", .(.fmt(ub,3)))), side=3, line=2.6, cex=.9, adj=0,
           col=col.tx)
     mtext(bquote(paste("  ", "n=", .(n1),
-       "   m=", .(.fmt(m1, digits_d)),"   s=", .(.fmt(sw, digits_d)))),
+       "   m=", .(.fmt(m1, digits_d)),"   s=", .(.fmt(sw, digits_d)),
+       "   d=", .(.fmt(smd, digits_d)))),
        side=3, line=1.3, cex=.9, adj=0, col=col.tx)
   }
 
