@@ -199,7 +199,7 @@ function(Y, Ynm, mu=NULL, n=NULL, m=NULL, s=NULL, brief, bw1,
       .lc.main(Y, type=NULL,
         col.line=getOption("pt_color"), col.area=NULL, col.box="black",
         col_color=getOption("pt_color"), 
-        col_fill=getOption("bar_fill_ordered"), shape_pts=21,
+        col_fill=getOption("bar_fill_cont"), shape_pts=21,
         col.bg=getOption("panel_fill"), lab_cex=getOption("lab_cex"),
         axis_cex=0.75, col.axis="gray30", rotate_x=0, rotate_y=0, offset=.5,
         xy_ticks=TRUE, line_width=1.1,
